sql — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

# sql

`camelot.core.sql.` `transaction`(original_function)

  Decorator for methods on an entity, to make them transactional

`camelot.core.sql.` `update_database_from_model`()

  Introspection the model and add missing columns in the database

  this function can be ran in setup_model after setup_all(create_tables=True)

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

Comments
blog comments powered by Disqus